@@ -409,7 +409,7 @@ size_t fwrite(const void *ptr, size_t size, size_t nmemb, FILE *stream) {
 /*
  * This is called whenever a thread is initialized
  */
-int
+static int
 _appio_init_thread( hwd_context_t *ctx )
 {
     ( void ) ctx;
@@ -422,7 +422,7 @@ _appio_init_thread( hwd_context_t *ctx )
  * and get hardware information, this routine is called when the 
  * PAPI process is initialized (IE PAPI_library_init)
  */
-int
+static int
 _appio_init_component( int cidx  )
 {
 
@@ -454,7 +454,7 @@ _appio_init_component( int cidx  )
  * Control of counters (Reading/Writing/Starting/Stopping/Setup)
  * functions
  */
-int
+static int
 _appio_init_control_state( hwd_control_state_t *ctl )
 {
     ( void ) ctl;
@@ -463,7 +463,7 @@ _appio_init_control_state( hwd_control_state_t *ctl )
 }
 
 
-int
+static int
 _appio_start( hwd_context_t *ctx, hwd_control_state_t *ctl )
 {
     ( void ) ctx;
@@ -481,7 +481,7 @@ _appio_start( hwd_context_t *ctx, hwd_control_state_t *ctl )
 }
 
 
-int
+static int
 _appio_read( hwd_context_t *ctx, hwd_control_state_t *ctl,
     long long ** events, int flags )
 {
@@ -503,7 +503,7 @@ _appio_read( hwd_context_t *ctx, hwd_control_state_t *ctl,
 }
 
 
-int
+static int
 _appio_stop( hwd_context_t *ctx, hwd_control_state_t *ctl )
 {
     (void) ctx;
@@ -524,7 +524,7 @@ _appio_stop( hwd_context_t *ctx, hwd_control_state_t *ctl )
 /*
  * Thread shutdown
  */
-int
+static int
 _appio_shutdown_thread( hwd_context_t *ctx )
 {
     ( void ) ctx;
@@ -536,7 +536,7 @@ _appio_shutdown_thread( hwd_context_t *ctx )
 /*
  * Clean up what was setup in appio_init_component().
  */
-int
+static int
 _appio_shutdown_component( void )
 {
     papi_free( _appio_native_events );
@@ -549,7 +549,7 @@ _appio_shutdown_component( void )
  * PAPI_SET_DOMAIN, PAPI_SETDEFGRN, PAPI_SET_GRANUL and
  * PAPI_SET_INHERIT
  */
-int
+static int
 _appio_ctl( hwd_context_t *ctx, int code, _papi_int_option_t *option )
 {
     ( void ) ctx;
@@ -560,7 +560,7 @@ _appio_ctl( hwd_context_t *ctx, int code, _papi_int_option_t *option )
 }
 
 
-int
+static int
 _appio_update_control_state( hwd_control_state_t *ctl,
         NativeInfo_t *native, int count, hwd_context_t *ctx )
 {
@@ -593,7 +593,7 @@ _appio_update_control_state( hwd_control_state_t *ctl,
  * PAPI_DOM_OTHER  is Exception/transient mode (like user TLB misses)
  * PAPI_DOM_ALL    is all of the domains
  */
-int
+static int
 _appio_set_domain( hwd_control_state_t *ctl, int domain )
 {
     ( void ) ctl;
@@ -609,7 +609,7 @@ _appio_set_domain( hwd_control_state_t *ctl, int domain )
 }
 
 
-int
+static int
 _appio_reset( hwd_context_t *ctx, hwd_control_state_t *ctl )
 {
     ( void ) ctx;
@@ -622,7 +622,7 @@ _appio_reset( hwd_context_t *ctx, hwd_control_state_t *ctl )
 /*
  * Native Event functions
  */
-int
+static int
 _appio_ntv_enum_events( unsigned int *EventCode, int modifier )
 {
     int index;
@@ -654,7 +654,7 @@ _appio_ntv_enum_events( unsigned int *EventCode, int modifier )
 /*
  *
  */
-int
+static int
 _appio_ntv_name_to_code( char *name, unsigned int *EventCode )
 {
     int i;
@@ -673,7 +673,7 @@ _appio_ntv_name_to_code( char *name, unsigned int *EventCode )
 /*
  *
  */
-int
+static int
 _appio_ntv_code_to_name( unsigned int EventCode, char *name, int len )
 {
     int index = EventCode;
@@ -690,7 +690,7 @@ _appio_ntv_code_to_name( unsigned int EventCode, char *name, int len )
 /*
  *
  */
-int
+static int
 _appio_ntv_code_to_descr( unsigned int EventCode, char *desc, int len )
 {
     int index = EventCode;
@@ -707,7 +707,7 @@ _appio_ntv_code_to_descr( unsigned int EventCode, char *desc, int len )
 /*
  *
  */
-int
+static int
 _appio_ntv_code_to_bits( unsigned int EventCode, hwd_register_t *bits )
 {
     int index = EventCode;
