@@ -516,7 +516,8 @@ detectDevices( )
 			SUBDBG("nvmlDeviceGetPciInfo() failed %s\n", (*nvmlErrorStringPtr)(ret) );
 			return PAPI_ESYS;
 		}
-		strncpy(nvml_busIds[i], info.busId, 16);
+		strncpy(nvml_busIds[i], info.busId, sizeof(nvml_busIds[i])-1);
+		nvml_busIds[i][sizeof(nvml_busIds[i])-1] = '\0';
 	}
 
 	/* We want to key our list of nvmlDevice_ts by each device's cuda index */
@@ -546,12 +547,14 @@ detectDevices( )
 				isUnique = 1;
 				features[i] = 0;
 
-				ret = (*nvmlDeviceGetNamePtr)( devices[i], name, 64 );
+				ret = (*nvmlDeviceGetNamePtr)( devices[i], name, sizeof(name)-1 );
 				if ( NVML_SUCCESS != ret) {
 					SUBDBG("nvmlDeviceGetName failed \n");
 					return PAPI_ESYS;
 				}
 
+				name[sizeof(name)-1] = '\0';	// to safely use strstr operation below, the variable 'name' must be null terminated
+
 				for (j=0; j < i; j++ ) 
 						if ( 0 == strncmp( name, names[j], 64 ) ) {
 								/* if we have a match, and IF everything is sane, 
@@ -578,7 +581,6 @@ detectDevices( )
 						ecc_version = strtof(inforomECC, NULL );
 						power_version = strtof( inforomPower, NULL);
 
-						ret = (*nvmlDeviceGetNamePtr)( devices[i], name, 64 );
 						isTesla = ( NULL == strstr(name, "Tesla") ) ? 0:1;
 
 						/* For Tesla and Quadro products from Fermi and Kepler families. */
@@ -652,8 +654,8 @@ this card. (nvml return code %d)\n", ret );
 								num_events += 2;
 						}
 
-						strncpy( names[i], name, 64); 
-
+						strncpy( names[i], name, sizeof(names[0])-1);
+						names[i][sizeof(names[0])-1] = '\0';
 				}
 		}
 		return PAPI_OK;
@@ -680,7 +682,8 @@ createNativeEvents( )
 		for (i=0; i < device_count; i++ ) {
 				memset( names[i], 0x0, 64 );
 				isUnique = 1;
-				ret = (*nvmlDeviceGetNamePtr)( devices[i], name, 64 );
+				ret = (*nvmlDeviceGetNamePtr)( devices[i], name, sizeof(name)-1 );
+				name[sizeof(name)-1] = '\0';	// to safely use strlen operation below, the variable 'name' must be null terminated
 
 				for (j=0; j < i; j++ ) 
 				{
@@ -892,7 +895,8 @@ createNativeEvents( )
 								entry->type = FEATURE_UTILIZATION;
 								entry++;
 						}
-						strncpy( names[i], name, 64); 
+						strncpy( names[i], name, sizeof(names[0])-1);
+						names[i][sizeof(names[0])-1] = '\0';
 				}
 		}
 }
@@ -1505,14 +1509,14 @@ _papi_nvml_ntv_code_to_info(unsigned int EventCode, PAPI_event_info_t *info)
 
   if ( ( index < 0) || (index >= num_events )) return PAPI_ENOEVNT;
 
-  strncpy( info->symbol, nvml_native_table[index].name, 
-     sizeof(info->symbol));
+  strncpy( info->symbol, nvml_native_table[index].name, sizeof(info->symbol)-1);
+  info->symbol[sizeof(info->symbol)-1] = '\0';
 
-  strncpy( info->units, nvml_native_table[index].units, 
-     sizeof(info->units));
+  strncpy( info->units, nvml_native_table[index].units, sizeof(info->units)-1);
+  info->units[sizeof(info->units)-1] = '\0';
 
-  strncpy( info->long_descr, nvml_native_table[index].description, 
-     sizeof(info->symbol));
+  strncpy( info->long_descr, nvml_native_table[index].description, sizeof(info->long_descr)-1);
+  info->long_descr[sizeof(info->long_descr)-1] = '\0';
 
 //  info->data_type = nvml_native_table[index].return_type;
 
