@@ -58,12 +58,19 @@
 #define PERF_EVENTS_OPENED  0x01
 #define PERF_EVENTS_RUNNING 0x02
 
-/* Static globals */
-int nmi_watchdog_active;
-
 /* Forward declaration */
 papi_vector_t _perf_event_vector;
 
+static int _pe_shutdown_thread( hwd_context_t *ctx );
+static int _pe_reset( hwd_context_t *ctx, hwd_control_state_t *ctl );
+static int _pe_write( hwd_context_t *ctx, hwd_control_state_t *ctl,
+                   long long *from );
+static int _pe_read( hwd_context_t *ctx, hwd_control_state_t *ctl,
+                  long long **events, int flags );
+static int _pe_start( hwd_context_t *ctx, hwd_control_state_t *ctl );
+static int _pe_stop( hwd_context_t *ctx, hwd_control_state_t *ctl );
+static int _pe_ctl( hwd_context_t *ctx, int code, _papi_int_option_t *option );
+
 /* Globals */
 struct native_event_table_t perf_native_event_table;
 static int our_cidx;
@@ -170,34 +177,6 @@ pe_vendor_fixups(papi_vector_t *vector)
 /******** Kernel Version Dependent Routines  **********************/
 /******************************************************************/
 
-/* KERNEL_CHECKS_SCHEDUABILITY_UPON_OPEN is a work-around for kernel arch
- * implementations (e.g. x86) which don't do a static event scheduability
- * check in sys_perf_event_open.
- * This was fixed for x86 in the 2.6.33 kernel
- *
- * Also! Kernels newer than 2.6.34 will fail in a similar way
- *       if the nmi_watchdog has stolen a performance counter
- *       and we try to use the maximum number of counters.
- *       A sys_perf_event_open() will seem to succeed but will fail
- *       at read time.  So re-use this work around code.
- */
-static int
-bug_check_scheduability(void) {
-
-#if defined(__powerpc__)
-  /* PowerPC not affected by this bug */
-#elif defined(__mips__)
-  /* MIPS as of kernel 3.1 does not properly detect schedulability */
-  return 1;
-#else
-  if (_papi_os_info.os_version < LINUX_VERSION(2,6,33)) return 1;
-#endif
-
-  if (nmi_watchdog_active) return 1;
-
-  return 0;
-}
-
 /* PERF_FORMAT_GROUP allows reading an entire group's counts at once   */
 /* before 2.6.34 PERF_FORMAT_GROUP did not work when reading results   */
 /*  from attached processes.  We are lazy and disable it for all cases */
@@ -498,68 +477,65 @@ check_scheduability( pe_context_t *ctx, pe_control_t *ctl, int idx )
    long long papi_pe_buffer[READ_BUFFER_SIZE];
    int i,group_leader_fd;
 
-   if (bug_check_scheduability()) {
+   /* If the kernel isn't tracking scheduability right       */
+   /* Then we need to start/stop/read to force the event     */
+   /* to be scheduled and see if an error condition happens. */
 
-      /* If the kernel isn't tracking scheduability right       */
-      /* Then we need to start/stop/read to force the event     */
-      /* to be scheduled and see if an error condition happens. */
+   /* get the proper fd to start */
+   group_leader_fd=ctl->events[idx].group_leader_fd;
+   if (group_leader_fd==-1) group_leader_fd=ctl->events[idx].event_fd;
 
-      /* get the proper fd to start */
-      group_leader_fd=ctl->events[idx].group_leader_fd;
-      if (group_leader_fd==-1) group_leader_fd=ctl->events[idx].event_fd;
+   /* start the event */
+   retval = ioctl( group_leader_fd, PERF_EVENT_IOC_ENABLE, NULL );
+   if (retval == -1) {
+      PAPIERROR("ioctl(PERF_EVENT_IOC_ENABLE) failed");
+      return PAPI_ESYS;
+   }
 
-      /* start the event */
-      retval = ioctl( group_leader_fd, PERF_EVENT_IOC_ENABLE, NULL );
-      if (retval == -1) {
-	 PAPIERROR("ioctl(PERF_EVENT_IOC_ENABLE) failed");
-	 return PAPI_ESYS;
-      }
+   /* stop the event */
+   retval = ioctl(group_leader_fd, PERF_EVENT_IOC_DISABLE, NULL );
+   if (retval == -1) {
+      PAPIERROR( "ioctl(PERF_EVENT_IOC_DISABLE) failed" );
+      return PAPI_ESYS;
+   }
 
-      /* stop the event */
-      retval = ioctl(group_leader_fd, PERF_EVENT_IOC_DISABLE, NULL );
-      if (retval == -1) {
-	 PAPIERROR( "ioctl(PERF_EVENT_IOC_DISABLE) failed" );
-	 return PAPI_ESYS;
-      }
+   /* See if a read returns any results */
+   cnt = read( group_leader_fd, papi_pe_buffer, sizeof(papi_pe_buffer));
+   if ( cnt == -1 ) {
+      SUBDBG( "read returned an error!  Should never happen.\n" );
+      return PAPI_ESYS;
+   }
 
-      /* See if a read returns any results */
-      cnt = read( group_leader_fd, papi_pe_buffer, sizeof(papi_pe_buffer));
-      if ( cnt == -1 ) {
-	 SUBDBG( "read returned an error!  Should never happen.\n" );
-	 return PAPI_ESYS;
-      }
+   if ( cnt == 0 ) {
+      /* We read 0 bytes if we could not schedule the event */
+      /* The kernel should have detected this at open       */
+      /* but various bugs (including NMI watchdog)          */
+      /* result in this behavior                            */
 
-      if ( cnt == 0 ) {
-         /* We read 0 bytes if we could not schedule the event */
-         /* The kernel should have detected this at open       */
-         /* but various bugs (including NMI watchdog)          */
-         /* result in this behavior                            */
+      return PAPI_ECNFLCT;
 
-	 return PAPI_ECNFLCT;
+   } else {
 
-     } else {
+      /* Reset all of the counters (opened so far) back to zero      */
+      /* from the above brief enable/disable call pair.              */
 
-	/* Reset all of the counters (opened so far) back to zero      */
-	/* from the above brief enable/disable call pair.              */
+      /* We have to reset all events because reset of group leader      */
+      /* does not reset all.                                            */
+      /* we assume that the events are being added one by one and that  */
+      /* we do not need to reset higher events (doing so may reset ones */
+      /* that have not been initialized yet.                            */
 
-	/* We have to reset all events because reset of group leader      */
-        /* does not reset all.                                            */
-	/* we assume that the events are being added one by one and that  */
-        /* we do not need to reset higher events (doing so may reset ones */
-        /* that have not been initialized yet.                            */
-
-	/* Note... PERF_EVENT_IOC_RESET does not reset time running       */
-	/* info if multiplexing, so we should avoid coming here if        */
-	/* we are multiplexing the event.                                 */
-        for( i = 0; i < idx; i++) {
-	   retval=ioctl( ctl->events[i].event_fd, PERF_EVENT_IOC_RESET, NULL );
-	   if (retval == -1) {
-	      PAPIERROR( "ioctl(PERF_EVENT_IOC_RESET) #%d/%d %d "
-			 "(fd %d)failed",
-			 i,ctl->num_events,idx,ctl->events[i].event_fd);
-	      return PAPI_ESYS;
-	   }
-	}
+      /* Note... PERF_EVENT_IOC_RESET does not reset time running       */
+      /* info if multiplexing, so we should avoid coming here if        */
+      /* we are multiplexing the event.                                 */
+      for( i = 0; i < idx; i++) {
+	 retval=ioctl( ctl->events[i].event_fd, PERF_EVENT_IOC_RESET, NULL );
+	 if (retval == -1) {
+	    PAPIERROR( "ioctl(PERF_EVENT_IOC_RESET) #%d/%d %d "
+		       "(fd %d)failed",
+		       i,ctl->num_events,idx,ctl->events[i].event_fd);
+	    return PAPI_ESYS;
+	 }
       }
    }
    return PAPI_OK;
@@ -869,7 +845,7 @@ _pe_set_domain( hwd_control_state_t *ctl, int domain)
 }
 
 /* Shutdown a thread */
-int
+static int
 _pe_shutdown_thread( hwd_context_t *ctx )
 {
     pe_context_t *pe_ctx = ( pe_context_t *) ctx;
@@ -883,7 +859,7 @@ _pe_shutdown_thread( hwd_context_t *ctx )
 /* reset the hardware counters */
 /* Note: PAPI_reset() does not necessarily call this */
 /* unless the events are actually running.           */
-int
+static int
 _pe_reset( hwd_context_t *ctx, hwd_control_state_t *ctl )
 {
    int i, ret;
@@ -908,7 +884,7 @@ _pe_reset( hwd_context_t *ctx, hwd_control_state_t *ctl )
 
 /* write (set) the hardware counters */
 /* Current we do not support this.   */
-int
+static int
 _pe_write( hwd_context_t *ctx, hwd_control_state_t *ctl,
 		long long *from )
 {
@@ -938,7 +914,7 @@ _pe_write( hwd_context_t *ctx, hwd_control_state_t *ctl,
  *
  */
 
-int
+static int
 _pe_read( hwd_context_t *ctx, hwd_control_state_t *ctl,
 	       long long **events, int flags )
 {
@@ -1140,7 +1116,7 @@ _pe_read( hwd_context_t *ctx, hwd_control_state_t *ctl,
 }
 
 /* Start counting events */
-int
+static int
 _pe_start( hwd_context_t *ctx, hwd_control_state_t *ctl )
 {
    int ret;
@@ -1184,7 +1160,7 @@ _pe_start( hwd_context_t *ctx, hwd_control_state_t *ctl )
 }
 
 /* Stop all of the counters */
-int
+static int
 _pe_stop( hwd_context_t *ctx, hwd_control_state_t *ctl )
 {
 	SUBDBG( "ENTER: ctx: %p, ctl: %p\n", ctx, ctl);
@@ -1217,7 +1193,7 @@ _pe_stop( hwd_context_t *ctx, hwd_control_state_t *ctl )
    updates it with whatever resources are allocated for all the native events
    in the native info structure array. */
 
-int
+static int
 _pe_update_control_state( hwd_control_state_t *ctl,
 			       NativeInfo_t *native,
 			       int count, hwd_context_t *ctx )
@@ -1347,7 +1323,7 @@ _pe_update_control_state( hwd_control_state_t *ctl,
 }
 
 /* Set various options on a control state */
-int
+static int
 _pe_ctl( hwd_context_t *ctx, int code, _papi_int_option_t *option )
 {
    int ret;
@@ -1521,7 +1497,7 @@ _pe_ctl( hwd_context_t *ctx, int code, _papi_int_option_t *option )
 }
 
 /* Initialize a thread */
-int
+static int
 _pe_init_thread( hwd_context_t *hwd_ctx )
 {
 
@@ -1537,7 +1513,7 @@ _pe_init_thread( hwd_context_t *hwd_ctx )
 }
 
 /* Initialize a new control state */
-int
+static int
 _pe_init_control_state( hwd_control_state_t *ctl )
 {
   pe_control_t *pe_ctl = ( pe_control_t *) ctl;
@@ -1613,7 +1589,7 @@ static int _pe_detect_rdpmc(int default_domain) {
 
 
 /* Initialize the perf_event component */
-int
+static int
 _pe_init_component( int cidx )
 {
 
@@ -1648,8 +1624,7 @@ _pe_init_component( int cidx )
   }
 
   /* Detect NMI watchdog which can steal counters */
-  nmi_watchdog_active=_linux_detect_nmi_watchdog();
-  if (nmi_watchdog_active) {
+  if (_linux_detect_nmi_watchdog()) {
     SUBDBG("The Linux nmi_watchdog is using one of the performance "
 	   "counters, reducing the total number available.\n");
   }
@@ -1721,7 +1696,7 @@ _pe_init_component( int cidx )
 }
 
 /* Shutdown the perf_event component */
-int
+static int
 _pe_shutdown_component( void ) {
 
   /* deallocate our event table */
@@ -1736,20 +1711,20 @@ _pe_shutdown_component( void ) {
 
 
 
-int
+static int
 _pe_ntv_enum_events( unsigned int *PapiEventCode, int modifier )
 {
   return _pe_libpfm4_ntv_enum_events(PapiEventCode, modifier,
                                        &perf_native_event_table);
 }
 
-int
+static int
 _pe_ntv_name_to_code( char *name, unsigned int *event_code) {
   return _pe_libpfm4_ntv_name_to_code(name,event_code,
                                         &perf_native_event_table);
 }
 
-int
+static int
 _pe_ntv_code_to_name(unsigned int EventCode,
                           char *ntv_name, int len) {
    return _pe_libpfm4_ntv_code_to_name(EventCode,
@@ -1757,7 +1732,7 @@ _pe_ntv_code_to_name(unsigned int EventCode,
 					&perf_native_event_table);
 }
 
-int
+static int
 _pe_ntv_code_to_descr( unsigned int EventCode,
                             char *ntv_descr, int len) {
 
@@ -1765,7 +1740,7 @@ _pe_ntv_code_to_descr( unsigned int EventCode,
                                           &perf_native_event_table);
 }
 
-int
+static int
 _pe_ntv_code_to_info(unsigned int EventCode,
                           PAPI_event_info_t *info) {
 
@@ -1947,7 +1922,7 @@ process_smpl_buf( int evt_idx, ThreadInfo_t **thr, int cidx )
  * software overflows are forced
  */
 
-void
+static void
 _pe_dispatch_timer( int n, hwd_siginfo_t *info, void *uc)
 {
   ( void ) n;                           /*unused */
@@ -2092,7 +2067,7 @@ _pe_dispatch_timer( int n, hwd_siginfo_t *info, void *uc)
 }
 
 /* Stop profiling */
-int
+static int
 _pe_stop_profiling( ThreadInfo_t *thread, EventSetInfo_t *ESI )
 {
   int i, ret = PAPI_OK;
@@ -2121,7 +2096,7 @@ _pe_stop_profiling( ThreadInfo_t *thread, EventSetInfo_t *ESI )
 }
 
 /* Setup an event to cause overflow */
-int
+static int
 _pe_set_overflow( EventSetInfo_t *ESI, int EventIndex, int threshold )
 {
 	SUBDBG("ENTER: ESI: %p, EventIndex: %d, threshold: %d\n", ESI, EventIndex, threshold);
@@ -2227,7 +2202,7 @@ _pe_set_overflow( EventSetInfo_t *ESI, int EventIndex, int threshold )
 }
 
 /* Enable profiling */
-int
+static int
 _pe_set_profile( EventSetInfo_t *ESI, int EventIndex, int threshold )
 {
   int ret;
