@@ -67,34 +67,6 @@ static int _peu_set_domain( hwd_control_state_t *ctl, int domain);
 /******** Kernel Version Dependent Routines  **********************/
 /******************************************************************/
 
-/* KERNEL_CHECKS_SCHEDUABILITY_UPON_OPEN is a work-around for kernel arch
- * implementations (e.g. x86) which don't do a static event scheduability
- * check in sys_perf_event_open.
- * This was fixed for x86 in the 2.6.33 kernel
- *
- * Also! Kernels newer than 2.6.34 will fail in a similar way
- *       if the nmi_watchdog has stolen a performance counter
- *       and we try to use the maximum number of counters.
- *       A sys_perf_event_open() will seem to succeed but will fail
- *       at read time.  So re-use this work around code.
- */
-static int
-bug_check_scheduability(void) {
-
-#if defined(__powerpc__)
-   /* PowerPC not affected by this bug */
-#elif defined(__mips__)
-   /* MIPS as of kernel 3.1 does not properly detect schedulability */
-   return 1;
-#else
-   if (_papi_os_info.os_version < LINUX_VERSION(2,6,33))
-	return 1;
-#endif
-
-   return 0;
-}
-
-
 /* The read format on perf_event varies based on various flags that */
 /* are passed into it.  This helper avoids copying this logic       */
 /* multiple places.                                                 */
@@ -258,68 +230,65 @@ check_scheduability( pe_context_t *ctx, pe_control_t *ctl)
    long long papi_pe_buffer[READ_BUFFER_SIZE];
    int i;
 
-   if (bug_check_scheduability()) {
+   /* If the kernel isn't tracking scheduability right       */
+   /* Then we need to start/stop/read to force the event     */
+   /* to be scheduled and see if an error condition happens. */
 
-	/* If the kernel isn't tracking scheduability right       */
-	/* Then we need to start/stop/read to force the event     */
-	/* to be scheduled and see if an error condition happens. */
+   /* start all events */
+   for( i = 0; i < ctl->num_events; i++) {
+      retval = ioctl( ctl->events[i].event_fd, PERF_EVENT_IOC_ENABLE, NULL );
+      if (retval == -1) {
+	 SUBDBG("EXIT: Enable failed event index: %d, num_events: %d, return PAPI_ESYS\n", i, ctl->num_events);
+	 return PAPI_ESYS;
+      }
+   }
 
-	/* start all events */
-	for( i = 0; i < ctl->num_events; i++) {
-	    retval = ioctl( ctl->events[i].event_fd, PERF_EVENT_IOC_ENABLE, NULL );
-	    if (retval == -1) {
-		SUBDBG("EXIT: Enable failed event index: %d, num_events: %d, return PAPI_ESYS\n", i, ctl->num_events);
-		return PAPI_ESYS;
-	    }
-	}
+   /* stop all events */
+   for( i = 0; i < ctl->num_events; i++) {
+      retval = ioctl(ctl->events[i].event_fd, PERF_EVENT_IOC_DISABLE, NULL );
+      if (retval == -1) {
+	 SUBDBG("EXIT: Disable failed: event index: %d, num_events: %d, return PAPI_ESYS\n", i, ctl->num_events);
+	 return PAPI_ESYS;
+      }
+   }
 
-	/* stop all events */
-	for( i = 0; i < ctl->num_events; i++) {
-	    retval = ioctl(ctl->events[i].event_fd, PERF_EVENT_IOC_DISABLE, NULL );
-	    if (retval == -1) {
-		SUBDBG("EXIT: Disable failed: event index: %d, num_events: %d, return PAPI_ESYS\n", i, ctl->num_events);
-		return PAPI_ESYS;
-	    }
-	}
+   /* See if a read of each event returns results */
+   for( i = 0; i < ctl->num_events; i++) {
+      cnt = read( ctl->events[i].event_fd, papi_pe_buffer, sizeof(papi_pe_buffer));
+      if ( cnt == -1 ) {
+	 SUBDBG( "EXIT: read failed: event index: %d, num_events: %d, return PAPI_ESYS.  Should never happen.\n", i, ctl->num_events);
+	 return PAPI_ESYS;
+      }
 
-	/* See if a read of each event returns results */
-	for( i = 0; i < ctl->num_events; i++) {
-	    cnt = read( ctl->events[i].event_fd, papi_pe_buffer, sizeof(papi_pe_buffer));
-	    if ( cnt == -1 ) {
-		SUBDBG( "EXIT: read failed: event index: %d, num_events: %d, return PAPI_ESYS.  Should never happen.\n", i, ctl->num_events);
-		return PAPI_ESYS;
-	    }
+      if ( cnt == 0 ) {
+	 /* We read 0 bytes if we could not schedule the event */
+	 /* The kernel should have detected this at open       */
+	 /* but various bugs (including NMI watchdog)          */
+	 /* result in this behavior                            */
 
-	    if ( cnt == 0 ) {
-		/* We read 0 bytes if we could not schedule the event */
-		/* The kernel should have detected this at open       */
-		/* but various bugs (including NMI watchdog)          */
-		/* result in this behavior                            */
+	 SUBDBG( "EXIT: read returned 0: event index: %d, num_events: %d, return PAPI_ECNFLCT.\n", i, ctl->num_events);
+	 return PAPI_ECNFLCT;
+      }
+   }
 
-		SUBDBG( "EXIT: read returned 0: event index: %d, num_events: %d, return PAPI_ECNFLCT.\n", i, ctl->num_events);
-		return PAPI_ECNFLCT;
-	    }
-	}
+   /* Reset all of the counters (opened so far) back to zero      */
+   /* from the above brief enable/disable call pair.              */
 
-	/* Reset all of the counters (opened so far) back to zero      */
-	/* from the above brief enable/disable call pair.              */
+   /* We have to reset all events because reset of group leader      */
+   /* does not reset all.                                            */
+   /* we assume that the events are being added one by one and that  */
+   /* we do not need to reset higher events (doing so may reset ones */
+   /* that have not been initialized yet.                            */
 
-	/* We have to reset all events because reset of group leader      */
-	/* does not reset all.                                            */
-	/* we assume that the events are being added one by one and that  */
-	/* we do not need to reset higher events (doing so may reset ones */
-	/* that have not been initialized yet.                            */
-
-	/* Note... PERF_EVENT_IOC_RESET does not reset time running       */
-	/* info if multiplexing, so we should avoid coming here if        */
-	/* we are multiplexing the event.                                 */
-	for( i = 0; i < ctl->num_events; i++) {
-	    retval=ioctl( ctl->events[i].event_fd, PERF_EVENT_IOC_RESET, NULL );
-	    if (retval == -1) {
-		SUBDBG("EXIT: Reset failed: event index: %d, num_events: %d, return PAPI_ESYS\n", i, ctl->num_events);
-		return PAPI_ESYS;
-	    }
-	}
+   /* Note... PERF_EVENT_IOC_RESET does not reset time running       */
+   /* info if multiplexing, so we should avoid coming here if        */
+   /* we are multiplexing the event.                                 */
+   for( i = 0; i < ctl->num_events; i++) {
+      retval=ioctl( ctl->events[i].event_fd, PERF_EVENT_IOC_RESET, NULL );
+      if (retval == -1) {
+	 SUBDBG("EXIT: Reset failed: event index: %d, num_events: %d, return PAPI_ESYS\n", i, ctl->num_events);
+	 return PAPI_ESYS;
+      }
    }
    SUBDBG("EXIT: return PAPI_OK\n");
    return PAPI_OK;
@@ -571,7 +540,7 @@ close_pe_events( pe_context_t *ctx, pe_control_t *ctl )
 
 
 /* Initialize a thread */
-int
+static int
 _peu_init_thread( hwd_context_t *hwd_ctx )
 {
 
@@ -588,7 +557,7 @@ _peu_init_thread( hwd_context_t *hwd_ctx )
 }
 
 /* Initialize a new control state */
-int
+static int
 _peu_init_control_state( hwd_control_state_t *ctl )
 {
   pe_control_t *pe_ctl = ( pe_control_t *) ctl;
@@ -613,7 +582,7 @@ _peu_init_control_state( hwd_control_state_t *ctl )
 
 
 /* Initialize the perf_event uncore component */
-int
+static int
 _peu_init_component( int cidx )
 {
 
@@ -687,7 +656,8 @@ _peu_init_component( int cidx )
 }
 
 /* Shutdown the perf_event component */
-int _peu_shutdown_component( void ) {
+static int
+_peu_shutdown_component( void ) {
 
   /* deallocate our event table */
   _peu_libpfm4_shutdown(&_perf_event_uncore_vector, &uncore_native_event_table);
@@ -841,7 +811,7 @@ _peu_set_domain( hwd_control_state_t *ctl, int domain)
 }
 
 /* Shutdown a thread */
-int
+static int
 _peu_shutdown_thread( hwd_context_t *ctx )
 {
     pe_context_t *pe_ctx = ( pe_context_t *) ctx;
@@ -855,7 +825,7 @@ _peu_shutdown_thread( hwd_context_t *ctx )
 /* reset the hardware counters */
 /* Note: PAPI_reset() does not necessarily call this */
 /* unless the events are actually running.           */
-int
+static int
 _peu_reset( hwd_context_t *ctx, hwd_control_state_t *ctl )
 {
    int i, ret;
@@ -880,7 +850,7 @@ _peu_reset( hwd_context_t *ctx, hwd_control_state_t *ctl )
 
 /* write (set) the hardware counters */
 /* Current we do not support this.   */
-int
+static int
 _peu_write( hwd_context_t *ctx, hwd_control_state_t *ctl,
 		long long *from )
 {
@@ -910,7 +880,7 @@ _peu_write( hwd_context_t *ctx, hwd_control_state_t *ctl,
  *
  */
 
-int
+static int
 _peu_read( hwd_context_t *ctx, hwd_control_state_t *ctl,
 	       long long **events, int flags )
 {
@@ -1074,7 +1044,7 @@ _peu_read( hwd_context_t *ctx, hwd_control_state_t *ctl,
 }
 
 /* Start counting events */
-int
+static int
 _peu_start( hwd_context_t *ctx, hwd_control_state_t *ctl )
 {
    int ret;
@@ -1118,7 +1088,7 @@ _peu_start( hwd_context_t *ctx, hwd_control_state_t *ctl )
 }
 
 /* Stop all of the counters */
-int
+static int
 _peu_stop( hwd_context_t *ctx, hwd_control_state_t *ctl )
 {
 
@@ -1146,7 +1116,7 @@ _peu_stop( hwd_context_t *ctx, hwd_control_state_t *ctl )
 }
 
 /* Set various options on a control state */
-int
+static int
 _peu_ctl( hwd_context_t *ctx, int code, _papi_int_option_t *option )
 {
    int ret;
@@ -1261,7 +1231,7 @@ _peu_ctl( hwd_context_t *ctx, int code, _papi_int_option_t *option )
 }
 
 
-int
+static int
 _peu_ntv_enum_events( unsigned int *PapiEventCode, int modifier )
 {
 
@@ -1272,7 +1242,7 @@ _peu_ntv_enum_events( unsigned int *PapiEventCode, int modifier )
                                        &uncore_native_event_table);
 }
 
-int
+static int
 _peu_ntv_name_to_code( char *name, unsigned int *event_code) {
 
   if (_perf_event_uncore_vector.cmp_info.disabled) return PAPI_ENOEVNT;
@@ -1281,7 +1251,7 @@ _peu_ntv_name_to_code( char *name, unsigned int *event_code) {
                                         &uncore_native_event_table);
 }
 
-int
+static int
 _peu_ntv_code_to_name(unsigned int EventCode,
                           char *ntv_name, int len) {
 
@@ -1292,7 +1262,7 @@ _peu_ntv_code_to_name(unsigned int EventCode,
 					 &uncore_native_event_table);
 }
 
-int
+static int
 _peu_ntv_code_to_descr( unsigned int EventCode,
                             char *ntv_descr, int len) {
 
@@ -1302,7 +1272,7 @@ _peu_ntv_code_to_descr( unsigned int EventCode,
                                           &uncore_native_event_table);
 }
 
-int
+static int
 _peu_ntv_code_to_info(unsigned int EventCode,
                           PAPI_event_info_t *info) {
 
